@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2019-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2019-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Module for communication with gvmd
@@ -27,11 +14,12 @@ from gvm.protocols.base import GvmConnection, GvmProtocol
 from gvm.protocols.gmpv208 import Gmp as Gmpv208
 from gvm.protocols.gmpv214 import Gmp as Gmpv214
 from gvm.protocols.gmpv224 import Gmp as Gmpv224
+from gvm.protocols.gmpv225 import Gmp as Gmpv225
 from gvm.transforms import EtreeCheckCommandTransform
 from gvm.xml import XmlCommand
 
 SUPPORTED_GMP_VERSIONS = Union[  # pylint: disable=invalid-name
-    Gmpv208, Gmpv214, Gmpv224
+    Gmpv208, Gmpv214, Gmpv224, Gmpv225
 ]
 
 
@@ -104,6 +92,8 @@ class Gmp(GvmProtocol):
             gmp_class = Gmpv214
         elif major_version == 22 and minor_version == 4:
             gmp_class = Gmpv224
+        elif major_version == 22 and minor_version == 5:
+            gmp_class = Gmpv225
         else:
             raise GvmError(
                 "Remote manager daemon uses an unsupported version of GMP. "
