@@ -1,26 +1,12 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-from enum import Enum
 from typing import Any, Optional
 
-from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
+from gvm._enum import Enum
+from gvm.errors import InvalidArgumentType, RequiredArgument
 from gvm.utils import add_filter, to_bool
 from gvm.xml import XmlCommand
 
@@ -34,22 +20,6 @@ class CredentialFormat(Enum):
     EXE = "exe"
     PEM = "pem"
 
-    @classmethod
-    def from_string(
-        cls,
-        credential_format: Optional[str],
-    ) -> Optional["CredentialFormat"]:
-        if not credential_format:
-            return None
-
-        try:
-            return cls[credential_format.upper()]
-        except KeyError:
-            raise InvalidArgument(
-                argument="credential_format",
-                function=cls.from_string.__name__,
-            ) from None
-
 
 class CredentialType(Enum):
     """Enum for credential types"""
@@ -62,23 +32,6 @@ class CredentialType(Enum):
     PGP_ENCRYPTION_KEY = "pgp"
     PASSWORD_ONLY = "pw"
 
-    @classmethod
-    def from_string(
-        cls,
-        credential_type: Optional[str],
-    ) -> Optional["CredentialType"]:
-        """Convert a credential type string into a CredentialType instance"""
-        if not credential_type:
-            return None
-
-        try:
-            return cls[credential_type.upper()]
-        except KeyError:
-            raise InvalidArgument(
-                argument="credential_type",
-                function=cls.from_string.__name__,
-            ) from None
-
 
 class SnmpAuthAlgorithm(Enum):
     """Enum for SNMP auth algorithm"""
@@ -86,24 +39,6 @@ class SnmpAuthAlgorithm(Enum):
     SHA1 = "sha1"
     MD5 = "md5"
 
-    @classmethod
-    def from_string(
-        cls,
-        algorithm: Optional[str],
-    ) -> Optional["SnmpAuthAlgorithm"]:
-        """Convert a SNMP auth algorithm string into a
-        SnmpAuthAlgorithm instance"""
-        if not algorithm:
-            return None
-
-        try:
-            return cls[algorithm.upper()]
-        except KeyError:
-            raise InvalidArgument(
-                argument="algorithm",
-                function=cls.from_string.__name__,
-            ) from None
-
 
 class SnmpPrivacyAlgorithm(Enum):
     """Enum for SNMP privacy algorithm"""
@@ -111,25 +46,6 @@ class SnmpPrivacyAlgorithm(Enum):
     AES = "aes"
     DES = "des"
 
-    @classmethod
-    def from_string(
-        cls,
-        algorithm: Optional[str],
-    ) -> Optional["SnmpPrivacyAlgorithm"]:
-        """Convert a SNMP privacy algorithm string into a SnmpPrivacyAlgorithm
-        instance
-        """
-        if not algorithm:
-            return None
-
-        try:
-            return cls[algorithm.upper()]
-        except KeyError:
-            raise InvalidArgument(
-                argument="algorithm",
-                function=cls.from_string.__name__,
-            ) from None
-
 
 class CredentialsMixin:
     def clone_credential(self, credential_id: str) -> Any:
