@@ -1,25 +1,12 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from enum import Enum
 from typing import Any, Optional
 
-from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
+from gvm._enum import Enum
+from gvm.errors import InvalidArgumentType, RequiredArgument
 from gvm.utils import add_filter, to_bool
 from gvm.xml import XmlCommand
 
@@ -34,22 +21,6 @@ class InfoType(Enum):
     OVALDEF = "OVALDEF"
     NVT = "NVT"
 
-    @classmethod
-    def from_string(cls, info_type: Optional[str]) -> Optional["InfoType"]:
-        """Convert a info type string to an actual InfoType instance
-
-        Arguments:
-            info_type: Info type string to convert to a InfoType
-        """
-        if not info_type:
-            return None
-        try:
-            return cls[info_type.upper()]
-        except KeyError:
-            raise InvalidArgument(
-                argument="info_type", function=cls.from_string.__name__
-            ) from None
-
 
 class SecInfoMixin:
     def get_nvt_families(self, *, sort_order: Optional[str] = None):
