@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Latest supported protocols, including unstable ones.
 
 This module exposes the latest supported protocols of GVM including versions
@@ -27,14 +14,14 @@ For details about the possible supported protocol versions please take a look at
 :py:mod:`gvm.protocols`.
 
 Exports:
-  - :py:class:`gvm.protocols.gmpv214.Gmp`
+  - :py:class:`gvm.protocols.gmpv225.Gmp`
   - :py:class:`gvm.protocols.ospv1.Osp`
 
 .. _Greenbone Management Protocol:
     https://docs.greenbone.net/API/GMP/gmp.html
 """
 
-from .gmpv214 import (
+from .gmpv225 import (
     AggregateStatistic,
     AlertCondition,
     AlertEvent,
@@ -52,6 +39,7 @@ from .gmpv214 import (
     PermissionSubjectType,
     PortRangeType,
     ReportFormatType,
+    ResourceType,
     ScannerType,
     SeverityLevel,
     SnmpAuthAlgorithm,
@@ -81,6 +69,7 @@ __all__ = [
     "PermissionSubjectType",
     "PortRangeType",
     "ReportFormatType",
+    "ResourceType",
     "ScannerType",
     "SeverityLevel",
     "SnmpAuthAlgorithm",
