@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2020-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2020-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
 import unittest
@@ -30,6 +17,7 @@ from gvm.connections import (
     DEFAULT_SSH_PASSWORD,
     DEFAULT_SSH_PORT,
     DEFAULT_SSH_USERNAME,
+    GvmConnection,
     SSHConnection,
 )
 from gvm.errors import GvmError
@@ -190,7 +178,7 @@ FsAQI=
         )
 
         with self.assertLogs("gvm.connections", level="INFO") as cm:
-            hostkeys = paramiko.HostKeys(filename=self.known_hosts_file)
+            hostkeys = paramiko.HostKeys(filename=str(self.known_hosts_file))
             ssh_connection._ssh_authentication_input_loop(
                 hostkeys=hostkeys, key=key
             )
@@ -242,7 +230,7 @@ FsAQI=
         )
 
         with self.assertLogs("gvm.connections", level="INFO") as cm:
-            hostkeys = paramiko.HostKeys(filename=self.known_hosts_file)
+            hostkeys = paramiko.HostKeys(filename=str(self.known_hosts_file))
             ssh_connection._ssh_authentication_input_loop(
                 hostkeys=hostkeys, key=key
             )
@@ -287,7 +275,7 @@ FsAQI=
         ssh_connection._socket = paramiko.SSHClient()
 
         with self.assertLogs("gvm.connections", level="INFO") as cm:
-            hostkeys = paramiko.HostKeys(filename=self.known_hosts_file)
+            hostkeys = paramiko.HostKeys(filename=str(self.known_hosts_file))
             ssh_connection._ssh_authentication_input_loop(
                 hostkeys=hostkeys, key=key
             )
@@ -336,7 +324,7 @@ FsAQI=
         with self.assertRaises(
             SystemExit, msg="User denied key. Host key verification failed."
         ):
-            hostkeys = paramiko.HostKeys(filename=self.known_hosts_file)
+            hostkeys = paramiko.HostKeys(filename=str(self.known_hosts_file))
             ssh_connection._ssh_authentication_input_loop(
                 hostkeys=hostkeys, key=key
             )
@@ -454,8 +442,7 @@ FsAQI=
             )
 
             ssh_connection.connect()
-            req = ssh_connection.send("blah")
-            self.assertEqual(req, 4)
+            ssh_connection.send("blah")
             ssh_connection.disconnect()
 
     def test_send_error(self):
@@ -486,8 +473,7 @@ FsAQI=
             )
 
             ssh_connection.connect()
-            req = ssh_connection.send("blah")
-            self.assertEqual(req, 4)
+            ssh_connection.send("blah")
 
             stdin.channel.send.assert_called()
             with self.assertRaises(AssertionError):
@@ -508,3 +494,7 @@ FsAQI=
             recved = ssh_connection._read()
             self.assertEqual(recved, b"foo bar baz")
             ssh_connection.disconnect()
+
+    def test_is_gvm_connection(self):
+        ssh_connection = SSHConnection(known_hosts_file=self.known_hosts_file)
+        self.assertTrue(isinstance(ssh_connection, GvmConnection))
