@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2019-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2019-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from unittest.mock import MagicMock, patch
@@ -23,6 +10,8 @@ from gvm.errors import GvmError
 from gvm.protocols.gmp import Gmp
 from gvm.protocols.gmpv208 import Gmp as Gmpv208
 from gvm.protocols.gmpv214 import Gmp as Gmpv214
+from gvm.protocols.gmpv224 import Gmp as Gmpv224
+from gvm.protocols.gmpv225 import Gmp as Gmpv225
 from tests.protocols import GmpTestCase
 
 
@@ -84,6 +73,28 @@ class GmpContextManagerTestCase(GmpTestCase):
             self.assertEqual(gmp.get_protocol_version(), (21, 4))
             self.assertIsInstance(gmp, Gmpv214)
 
+    def test_select_gmpv224(self):
+        self.connection.read.return_value(
+            '<get_version_response status="200" status_text="OK">'
+            "<version>22.04</version>"
+            "</get_version_response>"
+        )
+
+        with self.gmp as gmp:
+            self.assertEqual(gmp.get_protocol_version(), (22, 4))
+            self.assertIsInstance(gmp, Gmpv224)
+
+    def test_select_gmpv225(self):
+        self.connection.read.return_value(
+            '<get_version_response status="200" status_text="OK">'
+            "<version>22.05</version>"
+            "</get_version_response>"
+        )
+
+        with self.gmp as gmp:
+            self.assertEqual(gmp.get_protocol_version(), (22, 5))
+            self.assertIsInstance(gmp, Gmpv225)
+
     def test_unknown_protocol(self):
         self.connection.read.return_value(
             '<get_version_response status="200" status_text="OK">'
