@@ -1,20 +1,7 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .test_clone_scan_config import GmpCloneScanConfigTestMixin
 from .test_create_scan_config import GmpCreateScanConfigTestMixin
@@ -45,3 +32,21 @@ from .test_modify_scan_config_set_nvt_selection import (
 from .test_modify_scan_config_set_scanner_preference import (
     GmpModifyScanConfigSetScannerPreferenceTestMixin,
 )
+
+__all__ = (
+    "GmpCloneScanConfigTestMixin",
+    "GmpCreateScanConfigTestMixin",
+    "GmpDeleteScanConfigTestMixin",
+    "GmpGetScanConfigTestMixin",
+    "GmpGetScanConfigPreferenceTestMixin",
+    "GmpGetScanConfigPreferencesTestMixin",
+    "GmpGetScanConfigsTestMixin",
+    "GmpImportScanConfigTestMixin",
+    "GmpModifyScanConfigTestMixin",
+    "GmpModifyScanConfigSetCommentTestMixin",
+    "GmpModifyScanConfigSetFamilySelectionTestMixin",
+    "GmpModifyScanConfigSetNameTestMixin",
+    "GmpModifyScanConfigSetNvtPreferenceTestMixin",
+    "GmpModifyScanConfigSetNvtSelectionTestMixin",
+    "GmpModifyScanConfigSetScannerPreferenceTestMixin",
+)
